<?php
// -----------------------------------------------------------------------
//
// $Id: search.php 195 2012-04-03 10:02:52Z raoul $
//
// Copyright (C) 2003-2012 Raoul Proena
// License: GNU GPL version 3 (see copying.txt file)
// Website: http://www.gnew.fr/
//
// -----------------------------------------------------------------------
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// -----------------------------------------------------------------------

include('./../includes/common.php');

page_header($lang['COMMENTS_SEARCH_TITLE']);

if (isset($_GET['search']))
{
    // Clean and format string
    $pattern = array('`[ ]+`', '`[?]+`');
    $replace = array(' ', '?');
    $str = preg_replace($pattern, $replace, trim($_GET['search']));
    $str = chars2entities($str, ENT_QUOTES);

    $search = '';
    for ($i = 0; $i < strlen($str); $i++)
    {
        if (preg_match('`[a-z0-9&#;]`i', $str{$i}))
        {
            $search .= $str{$i};
        }
        elseif ($str{$i} == ' ')
        {
            $search .= '%';
        }
        elseif ($str{$i} == '?')
        {
            $search .= '_';
        }
        else
        {
            $search .= '';
        }
    }

    // HTML entities
    preg_match_all('`&[^;\s]+;`', $search, $entities);
    $num_entities = $offset = 0;
    for ($i = 0; $i < sizeof($entities[0]); $i++)
    {
        $num_entities++;
        $offset += strlen($entities[0][$i]);
    }

    // Check string
    if (!empty($search) && (strlen($search) - $offset + $num_entities) >= 2)
    {
        $num_comments = 0;
        $date_format = get_date_format();
        $date_offset = get_date_offset();
        $template->set_file('search', 'comments/search.htpl');
        $template->set_block('search', 'COMMENTS_BLOCK', 'comments');
        $sql->query('SELECT ' . TABLE_COMMENTS . '.comment_creation, ' . TABLE_COMMENTS . '.comment_edition, ' . TABLE_COMMENTS . '.comment_id, ' . TABLE_COMMENTS . '.comment_subject, ' . TABLE_COMMENTS . '.comment_text, ' . TABLE_COMMENTS . '.news_id, ' . TABLE_COMMENTS . '.story_id, ' . TABLE_USERS . '.user_avatar, ' . TABLE_USERS . '.user_id, ' . TABLE_USERS . '.user_name
                     FROM ' . TABLE_COMMENTS . ', ' . TABLE_USERS . '
                     WHERE ' . TABLE_COMMENTS . '.news_id = \'' . $_GET['news_id'] . '\'
                     AND ' . TABLE_COMMENTS . '.user_id = ' . TABLE_USERS . '.user_id
                     AND LOWER(' . TABLE_COMMENTS . '.' . $_GET['match'] . ') LIKE \'%' . strtolower($search) . '%\'
                     ORDER BY comment_creation DESC
                     LIMIT 0, ' . $settings['search_limit']);
        while ($table_comments = $sql->fetch())
        {
            // Count comments
            $num_comments++;

            // Temporary tags to delimit search string - only elements outside HTML tags are highlighted
            $comment_subject = '<!-- GENU_TEMP -->' . $table_comments['comment_subject'] . '<!-- GENU_TEMP -->';
            $comment_text = '<!-- GENU_TEMP -->' . $table_comments['comment_text'] . '<!-- GENU_TEMP -->';

            $element = explode('%', $search);
            for ($i = 0; $i < count($element); $i++)
            {
                // Highlight elements
                if ($_GET['match'] == 'comment_subject')
                {
                    $comment_subject = preg_replace('`([^&])(\b' . $element[$i] . '\b)([^;]){0,1}(?=[^>]*<)`i', '\\1<span class="newItem">\\2</span>\\3', $comment_subject);
                }
                if ($_GET['match'] == 'comment_text')
                {
                    $comment_text = preg_replace('`([^&])(\b' . $element[$i] . '\b)([^;]){0,1}(?=[^>]*<)`i', '\\1<span class="newItem">\\2</span>\\3', $comment_text);
                }
            }

            // Remove temporary tags
            $comment_subject = str_replace('<!-- GENU_TEMP -->', '', $comment_subject);
            $comment_text = str_replace('<!-- GENU_TEMP -->', '', $comment_text);

            $comment_creation = date($date_format, ($table_comments['comment_creation'] + $date_offset));
            $comment_edition = date($date_format, ($table_comments['comment_edition'] + $date_offset));
            if ($table_comments['comment_edition'])
            {
                $comment_edition = sprintf($lang['COMMENTS_INDEX_EDITION'], $comment_edition);
            }
            else
            {
                $comment_edition = '';
            }
            $comment_text = undo_escape_sequences($comment_text);
            $comment_text = cut_text($comment_text, './../comments/index.php?news_id=' . $table_comments['news_id'] . '&amp;story_id=' . $table_comments['story_id'] . '&amp;comment_id=' . $table_comments['comment_id']);
            $template->set_var(array('COMMENT_ID' => $table_comments['comment_id'],
                                     'COMMENT_EDITION' => $comment_edition,
                                     'COMMENT_RELEASE' => sprintf($lang['COMMENTS_SEARCH_RELEASE'], $table_comments['user_id'], $table_comments['user_name'], $comment_creation),
                                     'COMMENT_SUBJECT' => $comment_subject,
                                     'COMMENT_TEXT' => $comment_text,
                                     'NEWS_ID' => $table_comments['news_id'],
                                     'STORY_ID' => $table_comments['story_id'],
                                     'USER_AVATAR' => $table_comments['user_avatar']));
            $template->parse('COMMENTS_BLOCK', 'comments', true);
            $comments_exist = true;
        }
        if ($num_comments > $settings['search_limit'])
        {
            error_template(sprintf($lang['COMMENTS_SEARCH_ERROR1'], $settings['search_limit']));
        }
        else
        {
            if (isset($comments_exist))
            {
                    $string = chars2entities(stripslashes($_GET['search']), ENT_QUOTES);
                    $template->set_var(array('BACK_HOME' => $lang['BACK_HOME'],
                                             'COMMENTS_SEARCH_HEADER' => sprintf($lang['COMMENTS_SEARCH_HEADER'], $string, $num_comments)));
                    $template->parse('search');
            }
            else
            {
                error_template($lang['COMMENTS_SEARCH_ERROR2']);
            }
        }
    }
    else
    {
        error_template($lang['COMMENTS_SEARCH_ERROR3']);
    }
}
else
{
    error_template($lang['COMMENTS_SEARCH_ERROR4']);
}

page_footer();

?>