<?php
// -----------------------------------------------------------------------
//
// $Id: search.php 195 2012-04-03 10:02:52Z raoul $
//
// Copyright (C) 2003-2012 Raoul Proena
// License: GNU GPL version 3 (see copying.txt file)
// Website: http://www.gnew.fr/
//
// -----------------------------------------------------------------------
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// -----------------------------------------------------------------------

include('./../includes/common.php');

page_header($lang['POSTS_SEARCH_TITLE']);

if (isset($_GET['search']))
{
    // Clean and format string
    $pattern = array('`[ ]+`', '`[?]+`');
    $replace = array(' ', '?');
    $str = preg_replace($pattern, $replace, trim($_GET['search']));
    $str = chars2entities($str, ENT_QUOTES);

    $search = '';
    for ($i = 0; $i < strlen($str); $i++)
    {
        if (preg_match('`[a-z0-9&#;]`i', $str{$i}))
        {
            $search .= $str{$i};
        }
        elseif ($str{$i} == ' ')
        {
            $search .= '%';
        }
        elseif ($str{$i} == '?')
        {
            $search .= '_';
        }
        else
        {
            $search .= '';
        }
    }

    // HTML entities
    preg_match_all('`&[^;\s]+;`', $search, $entities);
    $num_entities = $offset = 0;
    for ($i = 0; $i < sizeof($entities[0]); $i++)
    {
        $num_entities++;
        $offset += strlen($entities[0][$i]);
    }

    // Check string
    if (!empty($search) && (strlen($search) - $offset + $num_entities) >= 2)
    {
        $num_posts = 0;
        $date_format = get_date_format();
        $date_offset = get_date_offset();
        $template->set_file('search', 'posts/search.htpl');
        $template->set_block('search', 'POSTS_BLOCK', 'posts');
        $sql->query('SELECT ' . TABLE_POSTS . '.category_id, ' . TABLE_POSTS . '.post_creation, ' . TABLE_POSTS . '.post_subject, ' . TABLE_POSTS . '.post_text, ' . TABLE_POSTS . '.thread_id, ' . TABLE_USERS . '.user_avatar, ' . TABLE_USERS . '.user_id, ' . TABLE_USERS . '.user_name
                     FROM ' . TABLE_POSTS . ', ' . TABLE_USERS . '
                     WHERE ' . TABLE_POSTS . '.category_id = \'' . $_GET['category_id'] . '\'
                     AND ' . TABLE_POSTS . '.user_id = ' . TABLE_USERS . '.user_id
                     AND LOWER(' . TABLE_POSTS . '.' . $_GET['match'] . ') LIKE \'%' . strtolower($search) . '%\'
                     ORDER BY post_creation DESC
                     LIMIT 0, ' . $settings['search_limit']);
        while ($table_posts = $sql->fetch())
        {
            // Count posts
            $num_posts++;

            // Temporary tags to delimit search string - only elements outside HTML tags are highlighted
            $post_subject = '<!-- GENU_TEMP -->' . $table_posts['post_subject'] . '<!-- GENU_TEMP -->';
            $post_text = '<!-- GENU_TEMP -->' . $table_posts['post_text'] . '<!-- GENU_TEMP -->';

            $element = explode('%', $search);
            for ($i = 0; $i < count($element); $i++)
            {
                // Highlight elements
                if ($_GET['match'] == 'post_subject')
                {
                    $post_subject = preg_replace('`([^&])(\b' . $element[$i] . '\b)([^;]){0,1}(?=[^>]*<)`i', '\\1<span class="newItem">\\2</span>\\3', $post_subject);
                }
                if ($_GET['match'] == 'post_text')
                {
                    $post_text = preg_replace('`([^&])(\b' . $element[$i] . '\b)([^;]){0,1}(?=[^>]*<)`i', '\\1<span class="newItem">\\2</span>\\3', $post_text);
                }
            }

            // Remove temporary tags
            $post_subject = str_replace('<!-- GENU_TEMP -->', '', $post_subject);
            $post_text = str_replace('<!-- GENU_TEMP -->', '', $post_text);

            $post_creation = date($date_format, ($table_posts['post_creation'] + $date_offset));
            $post_text = undo_escape_sequences($post_text);
            $post_text = cut_text($post_text, './../posts/read.php?category_id=' . $table_posts['category_id'] . '&amp;thread_id=' . $table_posts['thread_id']);
            $template->set_var(array('CATEGORY_ID' => $table_posts['category_id'],
                                     'POST_RELEASE' => sprintf($lang['POSTS_SEARCH_RELEASE'], $table_posts['user_id'], $table_posts['user_name'], $post_creation),
                                     'POST_SUBJECT' => $post_subject,
                                     'POST_TEXT' => $post_text,
                                     'THREAD_ID' => $table_posts['thread_id'],
                                     'USER_AVATAR' => $table_posts['user_avatar']));
            $template->parse('POSTS_BLOCK', 'posts', true);
            $posts_exist = true;
        }
        if ($num_posts > $settings['search_limit'])
        {
            error_template(sprintf($lang['POSTS_SEARCH_ERROR1'], $settings['search_limit']));
        }
        else
        {
            if (isset($posts_exist))
            {
                    $string = chars2entities(stripslashes($_GET['search']), ENT_QUOTES);
                    $template->set_var(array('BACK_THREADS_INDEX' => $lang['BACK_THREADS_INDEX'],
                                             'POSTS_SEARCH_HEADER' => sprintf($lang['POSTS_SEARCH_HEADER'], $string, $num_posts)));
                    $template->parse('search');
            }
            else
            {
                error_template($lang['POSTS_SEARCH_ERROR2']);
            }
        }
    }
    else
    {
        error_template($lang['POSTS_SEARCH_ERROR3']);
    }
}
else
{
    error_template($lang['POSTS_SEARCH_ERROR4']);
}

page_footer();

?>